==> dde-control-center_6.0.20.tar.xz: BUILD/translations/keyboard_language_en_US.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="en_US" version="2.1">
<context>
    <name>dcc::keyboard::Language</name>
    <message>
        <source>Afar</source>
        <translation>Afar</translation>
    </message>
    <message>
        <source>Afrikaans</source>
        <translation>Afrikaans</translation>
    </message>
    <message>
        <source>አማርኛ</source>
        <translation>Amharic</translation>
    </message>
    <message>
        <source>عربية</source>
        <translation>Arabic</translation>
    </message>
    <message>
        <source>অসমীয়া</source>
        <translation>Assamese</translation>
    </message>
    <message>
        <source>Asturianu</source>
        <translation>Asturian</translation>
    </message>
    <message>
        <source>Беларуская</source>
        <translation>Belarusian</translation>
    </message>
    <message>
        <source>Biełaruskaja łacinka</source>
        <translation>Belarusian Latin</translation>
    </message>
    <message>
        <source>Български</source>
        <translation>Bulgarian</translation>
    </message>
    <message>
        <source>বাংলা</source>
        <translation>Bengali</translation>
    </message>
    <message>
        <source>বাংলা (ভারত)</source>
        <translation>Bengali (India)</translation>
    </message>
    <message>
        <source>བོད་སྐད།</source>
        <translation>Tibetan</translation>
    </message>
    <message>
        <source>Brezhoneg</source>
        <translation>Breton</translation>
    </message>
    <message>
        <source>Bosanski</source>
        <translation>Bosnian</translation>
    </message>
    <message>
        <source>Català</source>
        <translation>Catalan</translation>
    </message>
    <message>
        <source>Qırımtatarca</source>
        <translation>Crimean Turkish</translation>
    </message>
    <message>
        <source>Český</source>
        <translation>Czech</translation>
    </message>
    <message>
        <source>Kaszëbsczi</source>
        <translation>Kashubian</translation>
    </message>
    <message>
        <source>Чăвашла</source>
        <translation>Chuvash</translation>
    </message>
    <message>
        <source>Cymraeg</source>
        <translation>Welsh</translation>
    </message>
    <message>
        <source>Dansk</source>
        <translation>Dansk</translation>
    </message>
    <message>
        <source>Deutsch</source>
        <translation>German</translation>
    </message>
    <message>
        <source>ཇོང་ཁ</source>
        <translation>Dzongkha</translation>
    </message>
    <message>
        <source>Ελληνικά</source>
        <translation>Greek</translation>
    </message>
    <message>
        <source>British English</source>
        <translation>British English</translation>
    </message>
    <message>
        <source>American English</source>
        <translation>American English</translation>
    </message>
    <message>
        <source>Español</source>
        <translation>Spanish</translation>
    </message>
    <message>
        <source>Eesti</source>
        <translation>Estonian</translation>
    </message>
    <message>
        <source>Euskara</source>
        <translation>Basque</translation>
    </message>
    <message>
        <source>فارسی</source>
        <translation>Persian</translation>
    </message>
    <message>
        <source>Suomi</source>
        <translation>Finnish</translation>
    </message>
    <message>
        <source>Føroyskt</source>
        <translation>Faroese</translation>
    </message>
    <message>
        <source>Français</source>
        <translation>French</translation>
    </message>
    <message>
        <source>Frysk</source>
        <translation>Western Frisian</translation>
    </message>
    <message>
        <source>Gaeilge</source>
        <translation>Irish</translation>
    </message>
    <message>
        <source>Gàidhlig</source>
        <translation>Gaelic</translation>
    </message>
    <message>
        <source>Galego</source>
        <translation>Galician</translation>
    </message>
    <message>
        <source>ગુજરાતી </source>
        <translation>Gujarati</translation>
    </message>
    <message>
        <source>Gaelg</source>
        <translation>Manx</translation>
    </message>
    <message>
        <source>هَوُسَ</source>
        <translation>Hausa</translation>
    </message>
    <message>
        <source>עברית</source>
        <translation>Hebrew</translation>
    </message>
    <message>
        <source>हिन्दी</source>
        <translation>Hindi</translation>
    </message>
    <message>
        <source>Chhattisgarhi</source>
        <translation>Chhattisgarhi</translation>
    </message>
    <message>
        <source>Hrvatski</source>
        <translation>Croatian</translation>
    </message>
    <message>
        <source>Hornjoserbsce</source>
        <translation>Upper Sorbian</translation>
    </message>
    <message>
        <source>Magyar</source>
        <translation>Hungarian</translation>
    </message>
    <message>
        <source>Հայերեն</source>
        <translation>Armenian</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Indonesian</translation>
    </message>
    <message>
        <source>Iñupiak</source>
        <translation>Inupiaq</translation>
    </message>
    <message>
        <source>Íslenska</source>
        <translation>Icelandic</translation>
    </message>
    <message>
        <source>Italiano</source>
        <translation>Italian</translation>
    </message>
    <message>
        <source>ᐃᓄᒃᑎᑐᑦ</source>
        <translation>Inuktitut</translation>
    </message>
    <message>
        <source>日本語</source>
        <translation>Japanese</translation>
    </message>
    <message>
        <source>ქართული</source>
        <translation>Georgian</translation>
    </message>
    <message>
        <source>Қазақша</source>
        <translation>Kazakh</translation>
    </message>
    <message>
        <source>Kalaallisut</source>
        <translation>Greenlandic</translation>
    </message>
    <message>
        <source>ខ្មែរ</source>
        <translation>Khmer</translation>
    </message>
    <message>
        <source>ಕನ್ನಡ</source>
        <translation>Kannada</translation>
    </message>
    <message>
        <source>한국어</source>
        <translation>Korean</translation>
    </message>
    <message>
        <source>कश्मीरी - (كشميري)</source>
        <translation>Kashmiri</translation>
    </message>
    <message>
        <source>Kurdî</source>
        <translation>Kurdish</translation>
    </message>
    <message>
        <source>Kernewek</source>
        <translation>Kurdish</translation>
    </message>
    <message>
        <source>Кыргызча</source>
        <translation>Kyrgyz</translation>
    </message>
    <message>
        <source>Lëtzebuergesch</source>
        <translation>Luxembourgish</translation>
    </message>
    <message>
        <source>Limburgs</source>
        <translation>Limburgian</translation>
    </message>
    <message>
        <source>ລາວ</source>
        <translation>Lao</translation>
    </message>
    <message>
        <source>Lietuvių</source>
        <translation>Lithuanian</translation>
    </message>
    <message>
        <source>Latviešu</source>
        <translation>Latvian</translation>
    </message>
    <message>
        <source>Maithili</source>
        <translation>Maithili</translation>
    </message>
    <message>
        <source>Malagasy</source>
        <translation>Malagasy</translation>
    </message>
    <message>
        <source>Ebon</source>
        <translation>Meadow Mari</translation>
    </message>
    <message>
        <source>Māori</source>
        <translation>Maori</translation>
    </message>
    <message>
        <source>Македонски</source>
        <translation>Macedonian</translation>
    </message>
    <message>
        <source>മലയാളം</source>
        <translation>Malayalam</translation>
    </message>
    <message>
        <source>Монгол</source>
        <translation>Mongolian</translation>
    </message>
    <message>
        <source>मराठी</source>
        <translation>Marathi</translation>
    </message>
    <message>
        <source>Bahasa Melayu</source>
        <translation>Malay</translation>
    </message>
    <message>
        <source>Malti</source>
        <translation>Maltese</translation>
    </message>
    <message>
        <source>Myanmasa</source>
        <translation>Burmese</translation>
    </message>
    <message>
        <source>Ekakairũ Naoero</source>
        <translation>Chinese (Min Nan) </translation>
    </message>
    <message>
        <source>Norsk (bokmål)</source>
        <translation>Norwegian Bokmål</translation>
    </message>
    <message>
        <source>Plattdüütsch</source>
        <translation>Low German</translation>
    </message>
    <message>
        <source>नेपाली</source>
        <translation>Nepali</translation>
    </message>
    <message>
        <source>Nederlands</source>
        <translation>Dutch</translation>
    </message>
    <message>
        <source>Norsk (nynorsk)</source>
        <translation>Norwegian (Nynorsk)</translation>
    </message>
    <message>
        <source>IsiNdebele</source>
        <translation>South Ndebele</translation>
    </message>
    <message>
        <source>Sesotho sa Leboa</source>
        <translation>Northern Sotho</translation>
    </message>
    <message>
        <source>Occitan</source>
        <translation>Occitan</translation>
    </message>
    <message>
        <source>Oromoo</source>
        <translation>Oromo</translation>
    </message>
    <message>
        <source>ଓଡ଼ିଆ</source>
        <translation>Oriya</translation>
    </message>
    <message>
        <source>Иронау</source>
        <translation>Ossetic</translation>
    </message>
    <message>
        <source>ਪੰਜਾਬੀ</source>
        <translation>Panjabi</translation>
    </message>
    <message>
        <source>Polski</source>
        <translation>Polish</translation>
    </message>
    <message>
        <source>پښتو</source>
        <translation>Pushto</translation>
    </message>
    <message>
        <source>Português</source>
        <translation>Portuguese</translation>
    </message>
    <message>
        <source>Português do Brasil</source>
        <translation>Portuguese (Brazil)</translation>
    </message>
    <message>
        <source>Română</source>
        <translation>Romanian</translation>
    </message>
    <message>
        <source>Русский</source>
        <translation>Russian</translation>
    </message>
    <message>
        <source>Kinyarwanda</source>
        <translation>Kinyarwanda</translation>
    </message>
    <message>
        <source>संस्कृत</source>
        <translation>Sanskrit</translation>
    </message>
    <message>
        <source>Sardu</source>
        <translation>Sardinian</translation>
    </message>
    <message>
        <source>سنڌي</source>
        <translation>Sindhi</translation>
    </message>
    <message>
        <source>Sámegiella</source>
        <translation>Northern Sami</translation>
    </message>
    <message>
        <source>සිංහල</source>
        <translation>Sinhala</translation>
    </message>
    <message>
        <source>Slovenčina</source>
        <translation>Slovak</translation>
    </message>
    <message>
        <source>Slovenščina</source>
        <translation>Slovenian</translation>
    </message>
    <message>
        <source>Soomaaliga</source>
        <translation>Somali</translation>
    </message>
    <message>
        <source>Shqip</source>
        <translation>Albanian</translation>
    </message>
    <message>
        <source>Српски</source>
        <translation>Serbian</translation>
    </message>
    <message>
        <source>srpski (latinica)</source>
        <translation>Serbian</translation>
    </message>
    <message>
        <source>SiSwati</source>
        <translation>Swati</translation>
    </message>
    <message>
        <source>Sesotho</source>
        <translation>Southern Sotho</translation>
    </message>
    <message>
        <source>Svenska</source>
        <translation>Swedish</translation>
    </message>
    <message>
        <source>Swahili</source>
        <translation>Swahili</translation>
    </message>
    <message>
        <source>தமிழ்</source>
        <translation>Tamil</translation>
    </message>
    <message>
        <source>తెలుగు</source>
        <translation>Telugu</translation>
    </message>
    <message>
        <source>Тоҷикӣ</source>
        <translation>Tajik</translation>
    </message>
    <message>
        <source>ภาษาไทย</source>
        <translation>Thai</translation>
    </message>
    <message>
        <source>ትግርኛ</source>
        <translation>Tigrinya</translation>
    </message>
    <message>
        <source>Türkmen</source>
        <translation>Turkmen</translation>
    </message>
    <message>
        <source>Setswana</source>
        <translation>Tswana</translation>
    </message>
    <message>
        <source>Türkçe</source>
        <translation>Turkish</translation>
    </message>
    <message>
        <source>Xitsonga</source>
        <translation>Tsonga</translation>
    </message>
    <message>
        <source>Татарский</source>
        <translation>Tatar</translation>
    </message>
    <message>
        <source>ئۇيغۇرچە</source>
        <translation>Uyghur</translation>
    </message>
    <message>
        <source>Українська</source>
        <translation>Ukrainian</translation>
    </message>
    <message>
        <source>اردو</source>
        <translation>Urdu</translation>
    </message>
    <message>
        <source>Oʻzbekcha</source>
        <translation>Uzbek</translation>
    </message>
    <message>
        <source>Uzbek (Cyrillic)</source>
        <translation>Uzbek (Cyrillic)</translation>
    </message>
    <message>
        <source>Venda</source>
        <translation>Venda</translation>
    </message>
    <message>
        <source>Tiếng Việt</source>
        <translation>Vietnamese</translation>
    </message>
    <message>
        <source>Walon</source>
        <translation>Walon</translation>
    </message>
    <message>
        <source>Wolof</source>
        <translation>Wolof</translation>
    </message>
    <message>
        <source>isixhosa</source>
        <translation>Xhosa</translation>
    </message>
    <message>
        <source>ייִדיש</source>
        <translation>Yiddish</translation>
    </message>
    <message>
        <source>Yorùbá</source>
        <translation>Yoruba</translation>
    </message>
    <message>
        <source>简体中文</source>
        <translation>Simplified Chinese</translation>
    </message>
    <message>
        <source>繁體中文（中國香港）</source>
        <translation>Tranditional Chinese (Hong Kong SAR, China)</translation>
    </message>
    <message>
        <source>繁體中文（中國臺灣）</source>
        <translation>Tranditional Chinese (Taiwan, China)</translation>
    </message>
    <message>
        <source>isiZulu</source>
        <translation>Zulu</translation>
    </message>
</context>
</TS>

==> dde-control-center_6.0.53.tar.xz: BUILD/translations/keyboard_language_en_US.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="en_US" version="2.1">
<context>
    <name>dcc::keyboard::Language</name>
    <message>
        <source>Afar</source>
        <translation>Afar</translation>
    </message>
    <message>
        <source>Afrikaans</source>
        <translation>Afrikaans</translation>
    </message>
    <message>
        <source>አማርኛ</source>
        <translation>Amharic</translation>
    </message>
    <message>
        <source>عربية</source>
        <translation>Arabic</translation>
    </message>
    <message>
        <source>অসমীয়া</source>
        <translation>Assamese</translation>
    </message>
    <message>
        <source>Asturianu</source>
        <translation>Asturian</translation>
    </message>
    <message>
        <source>Беларуская</source>
        <translation>Belarusian</translation>
    </message>
    <message>
        <source>Biełaruskaja łacinka</source>
        <translation>Belarusian Latin</translation>
    </message>
    <message>
        <source>Български</source>
        <translation>Bulgarian</translation>
    </message>
    <message>
        <source>বাংলা</source>
        <translation>Bengali</translation>
    </message>
    <message>
        <source>বাংলা (ভারত)</source>
        <translation>Bengali (India)</translation>
    </message>
    <message>
        <source>བོད་སྐད།</source>
        <translation>Tibetan</translation>
    </message>
    <message>
        <source>Brezhoneg</source>
        <translation>Breton</translation>
    </message>
    <message>
        <source>Bosanski</source>
        <translation>Bosnian</translation>
    </message>
    <message>
        <source>Català</source>
        <translation>Catalan</translation>
    </message>
    <message>
        <source>Qırımtatarca</source>
        <translation>Crimean Turkish</translation>
    </message>
    <message>
        <source>Český</source>
        <translation>Czech</translation>
    </message>
    <message>
        <source>Kaszëbsczi</source>
        <translation>Kashubian</translation>
    </message>
    <message>
        <source>Чăвашла</source>
        <translation>Chuvash</translation>
    </message>
    <message>
        <source>Cymraeg</source>
        <translation>Welsh</translation>
    </message>
    <message>
        <source>Dansk</source>
        <translation>Dansk</translation>
    </message>
    <message>
        <source>Deutsch</source>
        <translation>German</translation>
    </message>
    <message>
        <source>ཇོང་ཁ</source>
        <translation>Dzongkha</translation>
    </message>
    <message>
        <source>Ελληνικά</source>
        <translation>Greek</translation>
    </message>
    <message>
        <source>British English</source>
        <translation>British English</translation>
    </message>
    <message>
        <source>American English</source>
        <translation>American English</translation>
    </message>
    <message>
        <source>Español</source>
        <translation>Spanish</translation>
    </message>
    <message>
        <source>Eesti</source>
        <translation>Estonian</translation>
    </message>
    <message>
        <source>Euskara</source>
        <translation>Basque</translation>
    </message>
    <message>
        <source>فارسی</source>
        <translation>Persian</translation>
    </message>
    <message>
        <source>Suomi</source>
        <translation>Finnish</translation>
    </message>
    <message>
        <source>Føroyskt</source>
        <translation>Faroese</translation>
    </message>
    <message>
        <source>Français</source>
        <translation>French</translation>
    </message>
    <message>
        <source>Frysk</source>
        <translation>Western Frisian</translation>
    </message>
    <message>
        <source>Gaeilge</source>
        <translation>Irish</translation>
    </message>
    <message>
        <source>Gàidhlig</source>
        <translation>Gaelic</translation>
    </message>
    <message>
        <source>Galego</source>
        <translation>Galician</translation>
    </message>
    <message>
        <source>ગુજરાતી </source>
        <translation>Gujarati</translation>
    </message>
    <message>
        <source>Gaelg</source>
        <translation>Manx</translation>
    </message>
    <message>
        <source>هَوُسَ</source>
        <translation>Hausa</translation>
    </message>
    <message>
        <source>עברית</source>
        <translation>Hebrew</translation>
    </message>
    <message>
        <source>हिन्दी</source>
        <translation>Hindi</translation>
    </message>
    <message>
        <source>Chhattisgarhi</source>
        <translation>Chhattisgarhi</translation>
    </message>
    <message>
        <source>Hrvatski</source>
        <translation>Croatian</translation>
    </message>
    <message>
        <source>Hornjoserbsce</source>
        <translation>Upper Sorbian</translation>
    </message>
    <message>
        <source>Magyar</source>
        <translation>Hungarian</translation>
    </message>
    <message>
        <source>Հայերեն</source>
        <translation>Armenian</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Indonesian</translation>
    </message>
    <message>
        <source>Iñupiak</source>
        <translation>Inupiaq</translation>
    </message>
    <message>
        <source>Íslenska</source>
        <translation>Icelandic</translation>
    </message>
    <message>
        <source>Italiano</source>
        <translation>Italian</translation>
    </message>
    <message>
        <source>ᐃᓄᒃᑎᑐᑦ</source>
        <translation>Inuktitut</translation>
    </message>
    <message>
        <source>日本語</source>
        <translation>Japanese</translation>
    </message>
    <message>
        <source>ქართული</source>
        <translation>Georgian</translation>
    </message>
    <message>
        <source>Қазақша</source>
        <translation>Kazakh</translation>
    </message>
    <message>
        <source>Kalaallisut</source>
        <translation>Greenlandic</translation>
    </message>
    <message>
        <source>ខ្មែរ</source>
        <translation>Khmer</translation>
    </message>
    <message>
        <source>ಕನ್ನಡ</source>
        <translation>Kannada</translation>
    </message>
    <message>
        <source>한국어</source>
        <translation>Korean</translation>
    </message>
    <message>
        <source>कश्मीरी - (كشميري)</source>
        <translation>Kashmiri</translation>
    </message>
    <message>
        <source>Kurdî</source>
        <translation>Kurdish</translation>
    </message>
    <message>
        <source>Kernewek</source>
        <translation>Kurdish</translation>
    </message>
    <message>
        <source>Кыргызча</source>
        <translation>Kyrgyz</translation>
    </message>
    <message>
        <source>Lëtzebuergesch</source>
        <translation>Luxembourgish</translation>
    </message>
    <message>
        <source>Limburgs</source>
        <translation>Limburgian</translation>
    </message>
    <message>
        <source>ລາວ</source>
        <translation>Lao</translation>
    </message>
    <message>
        <source>Lietuvių</source>
        <translation>Lithuanian</translation>
    </message>
    <message>
        <source>Latviešu</source>
        <translation>Latvian</translation>
    </message>
    <message>
        <source>Maithili</source>
        <translation>Maithili</translation>
    </message>
    <message>
        <source>Malagasy</source>
        <translation>Malagasy</translation>
    </message>
    <message>
        <source>Ebon</source>
        <translation>Meadow Mari</translation>
    </message>
    <message>
        <source>Māori</source>
        <translation>Maori</translation>
    </message>
    <message>
        <source>Македонски</source>
        <translation>Macedonian</translation>
    </message>
    <message>
        <source>മലയാളം</source>
        <translation>Malayalam</translation>
    </message>
    <message>
        <source>Монгол</source>
        <translation>Mongolian</translation>
    </message>
    <message>
        <source>मराठी</source>
        <translation>Marathi</translation>
    </message>
    <message>
        <source>Bahasa Melayu</source>
        <translation>Malay</translation>
    </message>
    <message>
        <source>Malti</source>
        <translation>Maltese</translation>
    </message>
    <message>
        <source>Myanmasa</source>
        <translation>Burmese</translation>
    </message>
    <message>
        <source>Ekakairũ Naoero</source>
        <translation>Chinese (Min Nan) </translation>
    </message>
    <message>
        <source>Norsk (bokmål)</source>
        <translation>Norwegian Bokmål</translation>
    </message>
    <message>
        <source>Plattdüütsch</source>
        <translation>Low German</translation>
    </message>
    <message>
        <source>नेपाली</source>
        <translation>Nepali</translation>
    </message>
    <message>
        <source>Nederlands</source>
        <translation>Dutch</translation>
    </message>
    <message>
        <source>Norsk (nynorsk)</source>
        <translation>Norwegian (Nynorsk)</translation>
    </message>
    <message>
        <source>IsiNdebele</source>
        <translation>South Ndebele</translation>
    </message>
    <message>
        <source>Sesotho sa Leboa</source>
        <translation>Northern Sotho</translation>
    </message>
    <message>
        <source>Occitan</source>
        <translation>Occitan</translation>
    </message>
    <message>
        <source>Oromoo</source>
        <translation>Oromo</translation>
    </message>
    <message>
        <source>ଓଡ଼ିଆ</source>
        <translation>Oriya</translation>
    </message>
    <message>
        <source>Иронау</source>
        <translation>Ossetic</translation>
    </message>
    <message>
        <source>ਪੰਜਾਬੀ</source>
        <translation>Panjabi</translation>
    </message>
    <message>
        <source>Polski</source>
        <translation>Polish</translation>
    </message>
    <message>
        <source>پښتو</source>
        <translation>Pushto</translation>
    </message>
    <message>
        <source>Português</source>
        <translation>Portuguese</translation>
    </message>
    <message>
        <source>Português do Brasil</source>
        <translation>Portuguese (Brazil)</translation>
    </message>
    <message>
        <source>Română</source>
        <translation>Romanian</translation>
    </message>
    <message>
        <source>Русский</source>
        <translation>Russian</translation>
    </message>
    <message>
        <source>Kinyarwanda</source>
        <translation>Kinyarwanda</translation>
    </message>
    <message>
        <source>संस्कृत</source>
        <translation>Sanskrit</translation>
    </message>
    <message>
        <source>Sardu</source>
        <translation>Sardinian</translation>
    </message>
    <message>
        <source>سنڌي</source>
        <translation>Sindhi</translation>
    </message>
    <message>
        <source>Sámegiella</source>
        <translation>Northern Sami</translation>
    </message>
    <message>
        <source>සිංහල</source>
        <translation>Sinhala</translation>
    </message>
    <message>
        <source>Slovenčina</source>
        <translation>Slovak</translation>
    </message>
    <message>
        <source>Slovenščina</source>
        <translation>Slovenian</translation>
    </message>
    <message>
        <source>Soomaaliga</source>
        <translation>Somali</translation>
    </message>
    <message>
        <source>Shqip</source>
        <translation>Albanian</translation>
    </message>
    <message>
        <source>Српски</source>
        <translation>Serbian</translation>
    </message>
    <message>
        <source>srpski (latinica)</source>
        <translation>Serbian</translation>
    </message>
    <message>
        <source>SiSwati</source>
        <translation>Swati</translation>
    </message>
    <message>
        <source>Sesotho</source>
        <translation>Southern Sotho</translation>
    </message>
    <message>
        <source>Svenska</source>
        <translation>Swedish</translation>
    </message>
    <message>
        <source>Swahili</source>
        <translation>Swahili</translation>
    </message>
    <message>
        <source>தமிழ்</source>
        <translation>Tamil</translation>
    </message>
    <message>
        <source>తెలుగు</source>
        <translation>Telugu</translation>
    </message>
    <message>
        <source>Тоҷикӣ</source>
        <translation>Tajik</translation>
    </message>
    <message>
        <source>ภาษาไทย</source>
        <translation>Thai</translation>
    </message>
    <message>
        <source>ትግርኛ</source>
        <translation>Tigrinya</translation>
    </message>
    <message>
        <source>Türkmen</source>
        <translation>Turkmen</translation>
    </message>
    <message>
        <source>Setswana</source>
        <translation>Tswana</translation>
    </message>
    <message>
        <source>Türkçe</source>
        <translation>Turkish</translation>
    </message>
    <message>
        <source>Xitsonga</source>
        <translation>Tsonga</translation>
    </message>
    <message>
        <source>Татарский</source>
        <translation>Tatar</translation>
    </message>
    <message>
        <source>ئۇيغۇرچە</source>
        <translation>Uyghur</translation>
    </message>
    <message>
        <source>Українська</source>
        <translation>Ukrainian</translation>
    </message>
    <message>
        <source>اردو</source>
        <translation>Urdu</translation>
    </message>
    <message>
        <source>Oʻzbekcha</source>
        <translation>Uzbek</translation>
    </message>
    <message>
        <source>Uzbek (Cyrillic)</source>
        <translation>Uzbek (Cyrillic)</translation>
    </message>
    <message>
        <source>Venda</source>
        <translation>Venda</translation>
    </message>
    <message>
        <source>Tiếng Việt</source>
        <translation>Vietnamese</translation>
    </message>
    <message>
        <source>Walon</source>
        <translation>Walon</translation>
    </message>
    <message>
        <source>Wolof</source>
        <translation>Wolof</translation>
    </message>
    <message>
        <source>isixhosa</source>
        <translation>Xhosa</translation>
    </message>
    <message>
        <source>ייִדיש</source>
        <translation>Yiddish</translation>
    </message>
    <message>
        <source>Yorùbá</source>
        <translation>Yoruba</translation>
    </message>
    <message>
        <source>简体中文</source>
        <translation>Chinese (China)</translation>
    </message>
    <message>
        <source>繁體中文（中國香港）</source>
        <translation>Chinese (Chinese Hong Kong)</translation>
    </message>
    <message>
        <source>繁體中文（中國臺灣）</source>
        <translation>Chinese (Chinese Taiwan)</translation>
    </message>
    <message>
        <source>isiZulu</source>
        <translation>Zulu</translation>
    </message>
</context>
</TS>
